c 1 GETDISTANCE
c   Subroutine to determine the distance (in meters) 
c   between two pairs of positions.
c 2 USAGE
c   "a" = argument, "r" = referenced, "s" = set
c   
c   call getdistance                      (with the following arguments)
c          Position1x                  [variable r*8 a]
c          Position1y                  [variable r*8 a]
c          Position2x                  [variable r*8 a]
c          Position2y                  [variable r*8 a]
c          Distance                    [variable r*8 sr]
c 2 SUBROUTINES
c   typenav             (shared DAPS external routine)
c 2 LIMITATIONS
c   Positions can be either UTMx/UTMy pairs or Lat/Long pairs.
c   One position CAN NOT be UTMs with the other being Lat/Long.
c   Both UTM pairs are assumed to be based on the same UTM zone.
c   UTM positions within 360 meters of 0d lat and 0d long will be
c       interpreted as lat/longs not UTMs.
c   Lat/Longs may be on opposite sides of the International Date Line.
c   Longitudes must be between +/- 180.0
c   Identical input pairs results in a distance value of 0.0
c 

      subroutine getdistance (Position1x, Position1y,
     *                        Position2x, Position2y,
     *                        Distance)
      implicit none

      integer * 4 Zone1, Zone2

      real * 8 Position1x, Position1y
      real * 8 Position2x, Position2y

      real * 8 Latitude1, Longitude1
      real * 8 Latitude2, Longitude2, Longitude2Temp

      real * 8 UTMX1, UTMY1
      real * 8 UTMX2, UTMY2

      real * 8 Distance

      real * 8 Temporary1x, Temporary1y
      real * 8 Temporary2x, Temporary2y
      real * 8 DeltaX,  DeltaY

      character * 8 DataType

      call typenav (Position1x, Position1y,
     *              Position2x, Position2y,
     *              Temporary1x, Temporary1y,
     *              Temporary2x, Temporary2y,
     *              DataType)

c  bail out if UNKNOWN (UNACCEPTABLE) input

      if (DataType(1:7) .eq. 'UNKNOWN') then
          Distance = 0.0
      else
          if (DataType(1:8) .eq. 'LAT/LONG') then
              Latitude1 = Position1x
              Longitude1 = Position1y

              Latitude2 = Position2x
              Longitude2 = Position2y

              Zone1 = 0

              call geoutm (1, Latitude1, Longitude1,
     *               UTMX1, UTMY1, Zone1)

              Zone2 = 0

              call geoutm (1, Latitude2, Longitude2,
     *               UTMX2, UTMY2, Zone2)

c  if points turn out to be in different zones, 
c  force them into the same one

              if (Zone1 .ne. Zone2) then
                  call geoutm (1, Latitude2, Longitude2,
     *               UTMX2, UTMY2, Zone1)
              end if

              if (iabs(Zone1 - Zone2) .ge. 59) then
                  if (Zone1 .gt. Zone2) then
                      Longitude2Temp = Longitude2 - 360.0
                  else if (Zone1 .lt. Zone2) then
                      Longitude2Temp = Longitude2 + 360.0
                  end if

                  call geoutm (1, Latitude2, Longitude2Temp,
     *                UTMX2, UTMY2, Zone1)
              end if

              DeltaX = UTMX1 - UTMX2
              DeltaY = UTMY1 - UTMY2

              Distance = dsqrt ((DeltaX ** 2) + (DeltaY ** 2))

              if (Distance .gt. 99999.0) then
                  print *, 'Excessive getdistance ', Distance
                  print *, Zone1, Latitude1, Longitude1,
     *                     UTMX1, UTMX2, DeltaX
                  print *, Zone2, Latitude2, Longitude2,
     *                     UTMY1, UTMY2, DeltaY
              end if

          else if (DataType(1:3) .eq. 'UTM') then

              DeltaX = Temporary1x - Temporary2x
              DeltaY = Temporary1y - Temporary2y
               
              Distance = dsqrt ((DeltaX ** 2) + (DeltaY ** 2))
          end if
      end if


      return
      end
